@@ -165,16 +165,16 @@ class BaseRequest(HttpClient):
         self._timeout = timeout
 
     def get(self):
-        response = requests.get(self._uri, headers=self._headers, timeout=self._timeout)
+        response = requests.get(self.url, headers=self._headers, timeout=self._timeout)
         return response
 
     def post(self, payload: dict):
-        response = requests.post(self._uri, json=payload, headers=self._headers, timeout=self._timeout)
+        response = requests.post(self.url, json=payload, headers=self._headers, timeout=self._timeout)
         return response
 
     def put(self, payload: dict = None):
         payload = {} if payload is None else payload
-        response = requests.put(self._uri, json=payload, headers=self._headers, timeout=self._timeout)
+        response = requests.put(self.url, json=payload, headers=self._headers, timeout=self._timeout)
         return response
 
     def post_file(self, file, file_name: str, type_: int = 1, is_public=False):
@@ -211,7 +211,7 @@ class BaseRequest(HttpClient):
             file = getattr(file, 'file')
 
         response = requests.post(
-            url=self._uri,
+            url=self.url,
             data=data,
             files={"file": (new_file_name, file)},
             headers=self._headers,
@@ -225,7 +225,7 @@ class BaseRequest(HttpClient):
         return response
 
     @property
-    def _uri(self):
+    def url(self):
         local_url = 'http://127.0.0.1:8000'
         domain = f'https://{self._service}-dot-{self._project}.appspot.com' if self._service else local_url
         url = f'{domain}{self._path}'
