@@ -3,16 +3,19 @@ __all__ = ('SmsPoint',)
 from expressmoney.api import *
 
 
-SERVICE_NAME = 'notifications'
+SERVICE = 'notifications'
 
 
 class SmsCreateContract(Contract):
     message = serializers.CharField(min_length=1, max_length=60)
 
 
-notifications_sms_sms = ID(SERVICE_NAME, 'sms', 'sms')
+class SmsID(ID):
+    _service = SERVICE
+    _app = 'sms'
+    _view_set = 'sms'
 
 
 class SmsPoint(CreatePointMixin, ContractPoint):
-    _point_id = notifications_sms_sms
+    _point_id = SmsID()
     _create_contract = SmsCreateContract
