@@ -18,10 +18,10 @@ class BankCardCreateContract(GenericBankCard):
     cryptogram = serializers.CharField(max_length=1024)
 
 
-class BankCardResponseContract(BankCardCreateContract):
-    acs_url = serializers.URLField()
-    pa_req = serializers.CharField(max_length=1024)
-    md = serializers.CharField(max_length=1024)
+class BankCardResponseContract(Contract):
+    acs_url = serializers.URLField(required=False)
+    pa_req = serializers.CharField(required=False)
+    md = serializers.CharField(required=False)
 
 
 class BankCardReadContract(GenericBankCard):
@@ -54,7 +54,7 @@ class BankCard3dsID(ID):
     _view_set = 'bank_card_3ds'
 
 
-class BankCardPoint(ListPointMixin, CreatePointMixin, ContractPoint):
+class BankCardPoint(ListPointMixin, ResponseMixin, CreatePointMixin, ContractPoint):
     _point_id = BankCardID()
     _create_contract = BankCardCreateContract
     _response_contract = BankCardResponseContract
